new;
library pgraph;

data = loadd("cac-dj");

CAC40 = data[.,2];        /* CAC 40 */

y = ln(CAC40);
r = packr(y - lag1(y));   /* (log)returns of the CAC40 index */

muGaussian = meanc(r);    /* estimated parameters for the Gaussian distribution */
sigmaGaussian = stdc(r);

nu = 3;   /* df of the Student distribution */

muStudent = meanc(r);    /* estimated parameters for the Student distribution */
sigmaStudent = stdc(r)/sqrt(nu/(nu-2));

N = rows(r);             /* Number of observations of the database */

alpha = seqa(1/100,1/100,90);
x = cdfni(alpha^(1./N));
x1 = sigmaGaussian * x + muGaussian;
x = cdftci(1-alpha^(1./N),nu);
x2 = sigmaStudent * x + muStudent;

r = rev(sortc(r,1));
Nmax = 10;
rmax = r[1:Nmax];

graphset;
  begwind;
  window(1,2,0);
  _pnum = 2; _pframe = 0; 
  _paxht = 0.25; _pnumht = 0.20; _ptitlht = 0.25;
  fonts("simplex simgrma");
  ylabel("return (in percent)");
  xlabel("\202a\201");
  xtics(0,1,0.2,2);

  setwind(1);
    title("Gaussian distribution");
    _pline = ones(Nmax,1).*(1~3~0)~100*rmax~ones(Nmax,1)~100*rmax~ones(Nmax,1).*(1~15~0);
    ytics(4,7,0.5,0);
    xy(alpha,100*x1);

  setwind(2);
    title("Student distribution");
    ytics(5,20,2.5,0);
    xy(alpha,100*x2);

  graphprt("-c=1 -cf=cac2.ps");

  endwind;

let indx = 1 2 3 4 5 10 15 20;
rmax = r[indx];
x1 = (rmax - muGaussian) ./ sigmaGaussian;
Pr1 = 1-cdfn(x1)^N;

x2 = (rmax - muStudent) ./ sigmaStudent;
Pr2 = 1-(1-cdftc(x2,nu))^N;

output file = cac2.out reset;

call printfm(100*rmax~pr1~pr2,1~1~1,"%lf"~8~3);

output off;