new;
library pgraph;

rndseed 123;

N = 50;
M = 250;

data = 0.5*rndn(N,M) + 2;  /* random numbers */

x = maxc(data);            /* componentwise maximum */

proc ml(theta);
  local mu,sigma,xc,pdf;

  mu = theta[1];
  sigma = sqrt(theta[2]^2);

  xc = (x - mu)./sigma;
  pdf = N .* cdfn(xc)^(N-1) .* pdfn(xc) ./ sigma;

  retp( ln(pdf) );
endp;

proc negml(theta);
  retp( - sumc(ml(theta)) );
endp;

let sv = 1 1;
_qn_PrintIters = 1;

output file = g2.out reset;

{theta,f,g,retcode} = Qnewton(&negml,sv);   /* Optimization */

H = hessp(&negml,theta);                    /* - Hessian */
cov = invpd(H);                             /* Covariance matrix - form 1 */
stderr = sqrt(diag(cov));                   /* standard errors of the ML estimates */
tstudent = theta ./ miss(stderr,0);         /* test t */
df = rows(x) - rows(theta);                 /* degrees of freedom */
pvalue = 2*cdftc(abs(tstudent),df);         /* p-value */

let parnames = "mu" "sigma";
mask=0~1~1~1~1;
let fmt[5,3]=  "-*.*s"  8 8  "*.*lf" 16 6 "*.*lf" 16 6
               "*.*lf" 17 6  "*.*lf" 16 6;
omat = parnames~theta~stderr~tstudent~pvalue;

print;  print;
print "Parameters      estimates       std.err.    "\
      "  t-statistic         p-value   ";
print "-----------------------------------------"\
      "---------------------------------";
call printfm(omat,mask,fmt);

output off;

