new;
library optmum,pgraph;

rndseed 1234565;

#include mlegev.src;
#include gev.src;

data = loadd("cac-dj");

CAC40 = data[.,2];        /* CAC 40 */
DJ = data[.,3];           /* Dow Jones */

y = packr(CAC40~DJ);
data = ln(y);
r = data - lag1(data);
Nobs = rows(r);

varphi = 22;       /* one month of trading */

year = seqa(1,1,100);
tau = 265*year;                 /* return time (in trading days)  */
alpha = 1 - varphi/tau;         /* corresponding confidence level */

let sv = 0;
__output = 0;

stress_Short = zeros(100,2);
stress_Long = zeros(100,2);

i = 1;
do until i > 2;

  block = reshape(r[.,i],Nobs/varphi,varphi)';
  min = -minc(block);
  {mu,sigma,xi} = mleGEV(min,sv);

  stress_Long[.,i] = cdfGEVi(alpha,mu,sigma,xi);

  max = maxc(block);
  {mu,sigma,xi} = mleGEV(max,sv);

  stress_Short[.,i] = cdfGEVi(alpha,mu,sigma,xi);

  i = i + 1;
endo;

let indx = 5 10 25 50 75 100;

output file = gev3.out reset;

call printfm(-100*stress_Long[indx,.],1,"%lf"~8~2); print;
call printfm(100*stress_Short[indx,.],1,"%lf"~8~2); print;

output off;

graphset;
  _pdate = ""; _pnum = 2; _pframe = 0;
  _pltype = 6|3; _pstype = 8|9; _plctrl = 10;

  xtics(0,100,10,2);
  ytics(-40,0,10,2);
  xlabel("Return time (in years)");
  ylabel("Risk scale (in %)");

  _plegstr = "CAC40\000DowJones";
  _plegctl = {2 5 6.5 4.5};

  graphprt("-c=1 -cf=gev3.ps");

  xy(year,-100*stress_Long);

