new;
library optmum,pgraph;

rndseed 1234565;

#include gev.src;
#include mlegev.src;
#include copula.src;
#include gumbel.src;

data = loadd("cac-dj");

CAC40 = data[.,2];        /* CAC 40 */
DJ = data[.,3];           /* Dow Jones */

y = packr(CAC40~DJ);
data = ln(y);
r = data - lag1(data);
Nobs = rows(r);

varphi = 22;       /* one month of trading */
tau = 5;           /* Return time in years */

block_CAC40 = reshape(r[.,1],Nobs/varphi,varphi)';
block_DJ = reshape(r[.,2],Nobs/varphi,varphi)';

min_CAC40 = -minc(block_CAC40);
min_DJ = -minc(block_DJ);
max_CAC40 = maxc(block_CAC40);
max_CAC40 = maxc(block_DJ);

/*
**> Modelisation of the dependence of Min/Min 
**
*/

x1 = min_CAC40; 
x2 = min_DJ;

{mu,sigma,xi} = mleGEV(x1,0);
theta1 = mu|sigma|xi;
u1 = cdfGEV(x1,mu,sigma,xi);
{mu,sigma,xi} = mleGEV(x2,0);
theta2 = mu|sigma|xi;
u2 = cdfGEV(x2,mu,sigma,xi);
{alpha,stderr,logl} = mleGumbelCopula(u1,u2,1.25);

x1 = seqa(0,0.15/200,201);
x2 = x1';
u1 = cdfGEV(x1,theta1[1],theta1[2],theta1[3]);
u2 = cdfGEV(x2,theta2[1],theta2[2],theta2[3]);

cdf = cdfGumbelCopula(u1,u2,alpha);
tau = 265 * tau / varphi;                       /* return time in period of block */

stress1 = 100*cdfGEVi(1-1/tau,theta1[1],theta1[2],theta1[3]);  /* Univariate stress testing */
stress2 = 100*cdfGEVi(1-1/tau,theta2[1],theta2[2],theta2[3]);  /* Univariate stress testing */

e = (1 - u1 - u2 + cdf) .< (1/tau);  /* failure area with Gumbel Copula */

u2 = (1 - u1 - 1/tau)./(1-u1);
u2 = missex(u2,u2 .<= 0);

y1 = 100*cdfGEVi(u1,theta1[1],theta1[2],theta1[3]); 
y2 = 100*cdfGEVi(u2,theta2[1],theta2[2],theta2[3]); 
 
graphset;
  _pdate = ""; _pnum = 2; _pframe = 0;
  _pcross = 1;
  fonts("simplex simgrma");
  xtics(0,15,5,5);
  ytics(0,15,5,5);
  xlabel("\215CAC40 (in %)"); ylabel("\215DowJones (in %)");
  {row,col} = SpyPlot(e,0);
  _psym = 100*(x1[row]~x2[col]')~ones(rows(row),1).*(4~0.05~15~1~2);
  _pline = 1~6~stress1~0~stress1~15~1~11~5 |
           1~6~0~stress2~15~stress2~1~11~5 ;
  _pmsgstr = "C[+]\000C[\202\74\201]\000Gumbel";
  _pmsgctl =  10.1~10.25~0.15~0~1~12~5 |
              4.1~4.1~0.15~0~1~12~5 |
              6.25~8.25~0.15~-38~1~12~5 ; 
  graphprt("-c=1 -cf=stress1.ps");
  
  xy(y1,y2);

proc (2) = spyPlot(x,eps);
  local r_x,c_x,r,c,y;

  if eps == 0;
    eps = __macheps;
  endif;
  eps = abs(eps);

  r_x = rows(x);
  c_x = cols(x);

  r = vecr(seqa(1,1,r_x) .* ones(r_x,c_x));
  c = vecr(seqa(1,1,c_x)' .* ones(r_x,c_x));
  x = vecr(x);
  
  y = selif(r~c~x, x .> eps .or x .< -eps );

  r = y[.,1];
  c = y[.,2];
  
  retp(r,c);
endp;
